
## Download species occurrence records from GBIF and iNaturalist       


if (!require(tidyverse)) install.packages("tidyverse", dependencies = T)
if (!require(sf)) install.packages("sf", dependencies = T)
if (!require(rgbif)) install.packages("rgbif", dependencies = T)
if (!require(rinat)) install.packages("rinat", dependencies = T)


# 1. Get a list of species of interest 
splist <- read.csv('./species_list.csv')

#2. Download occurrences from GBIF https://www.gbif.org/
o.gbif <- occ_search(scientificName = splist$Species,
                     country = "CU",
                     limit = 10000,
                     fields = c("scientificName","species","decimalLatitude","decimalLongitude","basisOfRecord",
                                "individualCount","sex","municipality","gbifID",
                                "stateProvince","year","month","day",
                                "georeferenceProtocol" , "georeferencedBy", "locality", "recordedBy",
                                "coordinateUncertaintyInMeters", "institutionCode", "references", "datasetKey")
)

#List to save only the slot "data"
o.gbif.data <- vector("list", length = length(o.gbif))

#Extract data
for (i in seq_along(o.gbif)) {
  if(is.list(o.gbif[[i]][["data"]]))
    o.gbif.data[[i]] <- o.gbif[[i]][["data"]]
}


#Discard species with no records. All valid records in a dataframe
o.gbif.data2 <- discard(o.gbif.data, is.null)%>%
  bind_rows()

# Save results
write.csv(o.gbif.data2, row.names = F, "gbif_raw.csv")


# 3. Download records from iNaturalist https://www.inaturalist.org/
tax <- c('Insecta', 'Crustacea', 'Mollusca')
o.inat.l <- vector(mode = 'list', length = 3)
for (i in seq_along(tax)) {
  o.inat <- get_inat_obs(taxon_name = tax[i],
                         bounds = c(19.82597,-84.95236,23.27764,-74.13119),
                         maxresults = 10000)
  o.inat.f <- o.inat %>%
    filter(scientific_name %in% splist$Species)
  o.inat.l[[i]] <- o.inat.f
}

o.inat.raw <- bind_rows(o.inat.l, .id = "column_label")

# Save results
write.csv(o.inat.raw, "inat_raw.csv")








